@@ -4,31 +4,30 @@ use strict;
 use warnings;
 use FindBin::libs;
 
-use Method::Cached
+use Method::Cached::Manager
     -default => {
-        storage_class => 'Cache::Memcached::Fast',
-        storage_args  => [
+        class => 'Cache::Memcached::Fast',
+        args  => [
             { servers    => [qw/ 127.0.0.1:11211 /] },
         ],
     },
     -domains => {
         'memcached-fast' => {
-            storage_class => 'Cache::Memcached::Fast',
-            storage_args  => [
+            class => 'Cache::Memcached::Fast',
+            args  => [
                 { servers    => [qw/ 127.0.0.1:11211 /] },
             ],
             key_rule      => 'LIST', # SERIALIZE / LIST
         },
         'fastmmap'       => {
-            storage_class => 'Cache::FastMmap',
-            storage_args  => [
+            class => 'Cache::FastMmap',
+            args  => [
                 share_file     => '/tmp/fastmmap.bin',
                 unlink_on_exit => 1,
             ],
             key_rule      => 'LIST', # SERIALIZE / LIST
         },
-    },
-;
+    }, ;
 
 {
     package Dummy;
@@ -58,7 +57,6 @@ use Method::Cached
         return $n if $n < 2;
         fib_fastmmap($n - 1) + fib_fastmmap($n - 2);
     }
-
 }
 
 package main;
@@ -74,7 +72,7 @@ sub def_fib { $def_fib = $num; $def_fib = Dummy::fib_default($def_fib)  }
 sub mc_fib  { $mc_fib  = $num; $mc_fib  = Dummy::fib_memcached($mc_fib) }
 sub fm_fib  { $fm_fib  = $num; $fm_fib  = Dummy::fib_fastmmap($fm_fib)  }
 
-cmpthese(10000, {
+cmpthese(50000, {
     'fib'               => \&fib,
     'C(default)'        => \&def_fib,
     'C(Memcached-Fast)' => \&mc_fib,
